@@ -1,3 +1,4 @@
+import pydantic
 import platform
 import sys
 import pymongo
@@ -8,6 +9,7 @@ from pyodmongo import version
 def test_version():
     info = {
         "PyODMongo version": "__VERSION__",
+        "Pydantic version": pydantic.version.VERSION,
         "Pymongo version": pymongo.__version__,
         "Motor version": motor._version.version,
         "Python version": sys.version,
